* --------------------------------------------------------------------
* Project: The Effect of Information and Communication Technologies
*          on Urban Structure 
*          published in: Economic Policy, April 2008, pp. 201 - 242
* Authors: Yannis M. Ioannides, Henry G. Overman, 
*          Esteban Rossi-Hansberg, and Kurt Schmidheiny 
* Date:    December 7, 2007
* File:    table4.do
* Title:   Internet users, phone lines and the city size distribution
* --------------------------------------------------------------------

set more off
clear
use twostep.dta, clear

* --------------------------------------------------------------------
* restrict sample
* --------------------------------------------------------------------

* drop Germany
drop if countrycode == "DEU"

* restrict to Europe and Northern America
drop if ~(europe==1|northamerica==1)

* --------------------------------------------------------------------
* data structure
* --------------------------------------------------------------------

* panel structure
tsset countryid time 

* --------------------------------------------------------------------
* create sample specific time averages
* --------------------------------------------------------------------

* generate time constant averages
by countryid: egen govexp_avgpan = mean(govexp_mix)
lab var govexp_avgpan "=  mean(govexp_mix), years with city observations"
by countryid: egen obs_avgpan = mean(obs_cities_sc)
lab var obs_avgpan "=  mean(obs), years with city observations"

* --------------------------------------------------------------------
* estimation
* --------------------------------------------------------------------

estimates clear

* determine sample for regression with phone lines only: only countries we use in Table 2
quietly reg alpha05_lin_cities linternet_sc lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if year <= 2000
generate sample1 = e(sample)

* but allow years beyound 2000 for above countries
bysort countryid: egen sample2 = max(sample1) 

* common sample for all estimations
quietly reg alpha05_lin_cities linternet_sc lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample2
generate sample = e(sample)

* weights
generate weight = 1/(sealpha_lin_cities^2)

* column [1]: univariate, no fixed effects
reg alpha05_lin_cities linternet_sc time if sample [aw=weight]
estimates store m1

* column [2]: multivariate, no fixed effects
reg alpha05_lin_cities linternet_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m2

* column [3]: univariate, no fixed effects
reg alpha05_lin_cities linternet_sc lphones_sc time if sample [aw=weight]
estimates store m3

* column [4]: multivariate, no fixed effects
reg alpha05_lin_cities linternet_sc lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m4

* column [5], not reported: univariate, no fixed effects, IV
ivreg alpha05_lin_cities (linternet_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) time if sample [aw=weight]
estimates store m5

* column [6], not reported: multivariate, no fixed effects, IV
ivreg alpha05_lin_cities (linternet_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m6

* column [7], not reported: univariate, no fixed effects, IV
ivreg alpha05_lin_cities (linternet_sc lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) time if sample [aw=weight]
estimates store m7

* column [8], not reported: multivariate, no fixed effects, IV
ivreg alpha05_lin_cities (linternet_sc lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m8

* column [9], not reported: univariate, fixed effects
xi: reg alpha05_lin_cities linternet_sc i.countryid time if sample [aw=weight], 
estimates store m9

* column [10], not reported: multivariate, fixed effects
xi: reg alpha05_lin_cities linternet_sc invroaddens lnpop lngdppcppp trade nonagriva govexp_avgpan gdpgrowth_sd lnarea obs_avgpan i.countryid time if sample [aw=weight]
estimates store m10

* column [11], not reported: univariate, fixed effects
xi: reg alpha05_lin_cities linternet_sc lphones_sc i.countryid time if sample [aw=weight]
estimates store m11

* column [12], not reported: multivariate, fixed effects
xi: reg alpha05_lin_cities linternet_sc lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan i.countryid time if sample [aw=weight]
estimates store m12

* column [13], not reported: univariate, fixed effects, IV
xi: ivreg alpha05_lin_cities (linternet_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) i.countryid time if sample [aw=weight]
estimates store m13

* column [14], not reported: multivariate, fixed effects, IV
xi: ivreg alpha05_lin_cities (linternet_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva govexp_avgpan gdpgrowth_sd lnarea obs_avgpan i.countryid time if sample [aw=weight]
estimates store m14

* column [15], not reported: univariate, fixed effects, IV
xi: ivreg alpha05_lin_cities (linternet_sc lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) i.countryid time if sample [aw=weight]
estimates store m15

* column [16], not reported: multivariate, fixed effects, IV
xi: ivreg alpha05_lin_cities (linternet_sc lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan i.countryid time if sample [aw=weight]
estimates store m16

* produce output table, tab-delimited text
set linesize 255
estout * using table4.txt, stats(r2 N N_g rss) cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) margin legend replace
estimates clear

* --------------------------------------------------------------------
* descriptive statistics
* --------------------------------------------------------------------

sum internet_sc linternet_sc phones_sc lphones_sc invroaddens pop lnpop gdppcppp lngdppcppp trade nonagriva govexp_avgpan gdpgrowth_sd landarea lnarea obs_avgpan if sample
