* --------------------------------------------------------------------
* Project: The Effect of Information and Communication Technologies
*          on Urban Structure 
*          published in: Economic Policy, April 2008, pp. 201 - 242
* Authors: Yannis M. Ioannides, Henry G. Overman, 
*          Esteban Rossi-Hansberg, and Kurt Schmidheiny 
* Date:    December 7, 2007
* File:    tableA1.do
* Title:   Phone lines and the city size distribution (one-step estimation)
* --------------------------------------------------------------------

set more off
clear
use onestep.dta, clear

* --------------------------------------------------------------------
* restrict sample
* --------------------------------------------------------------------

* drop Germany
drop if countrycode == "DEU"

* restrict to Europe and Northern America
drop if ~(europe==1|northamerica==1)

* restrict to observations up to 2000
drop if year > 2000

* restrict to observations with phone data
drop if lnrank05 ==. | phones==.

* --------------------------------------------------------------------
* data structure
* --------------------------------------------------------------------

* set panel structure, 
* such that country-year specific constants are estimated
tsset countryyear cityid

* create country dummies, reference is USA
char countryid[omit] 198
xi i.countryid*lnpopcnorm

* --------------------------------------------------------------------
* estimation
* --------------------------------------------------------------------

estimates clear

* common sample for all estimations
quietly xtreg lnrank05 lnpopcnorm lphon2lpopcn ird2lpopcn lpop2lpopcn lgdpp2lpopcn trade2lpopcn nonagr2lpopcn govavgpan2lpopcn gdpsd2lpopcn larea2lpopcn obsavgpan2lpopcn time2lpopcn, fe
generate sample = e(sample)

* OLS, no fixed effects
xtreg lnrank05 lnpopcnorm time2lpopcn if sample, fe 
estimates store m0
xtreg lnrank05 lnpopcnorm lphon2lpopcn time2lpopcn if sample, fe 
estimates store m1
xtreg lnrank05 lnpopcnorm lphon2lpopcn ird2lpopcn lpop2lpopcn lgdpp2lpopcn trade2lpopcn nonagr2lpopcn govavgpan2lpopcn gdpsd2lpopcn larea2lpopcn obsavgpan2lpopcn time2lpopcn, fe 
estimates store m2

* OLS, fixed effects
xtreg lnrank05 lnpopcnorm _IcouXlnp_* lphon2lpopcn time2lpopcn if sample, fe 
estimates store m3
xtreg lnrank05 lnpopcnorm _IcouXlnp_* lphon2lpopcn trade2lpopcn ird2lpopcn lpop2lpopcn time2lpopcn nonagr2lpopcn lgdpp2lpopcn if sample, fe 
estimates store m4

* IV, no fixed effects
xtivreg lnrank05 lnpopcnorm (lphon2lpopcn = monopu2lpopcn monopr2lpopcn timemonopu2lpopcn timemonopr2lpopcn eu2lpopcn nafta2lpopcn) time2lpopcn if sample, fe 
estimates store m5
xtivreg lnrank05 lnpopcnorm (lphon2lpopcn = monopu2lpopcn monopr2lpopcn timemonopu2lpopcn timemonopr2lpopcn eu2lpopcn nafta2lpopcn) ird2lpopcn lpop2lpopcn lgdpp2lpopcn trade2lpopcn nonagr2lpopcn govavgpan2lpopcn gdpsd2lpopcn larea2lpopcn obsavgpan2lpopcn time2lpopcn, fe
estimates store m6

* IV, fixed effects
xtivreg lnrank05 lnpopcnorm _IcouXlnp_* (lphon2lpopcn = monopu2lpopcn monopr2lpopcn timemonopu2lpopcn timemonopr2lpopcn eu2lpopcn nafta2lpopcn) time2lpopcn if sample, fe first
estimates store m7
xtivreg lnrank05 lnpopcnorm _IcouXlnp_* (lphon2lpopcn = monopu2lpopcn monopr2lpopcn timemonopu2lpopcn timemonopr2lpopcn eu2lpopcn nafta2lpopcn) ird2lpopcn lpop2lpopcn time2lpopcn trade2lpopcn nonagr2lpopcn lgdpp2lpopcn if sample, fe first
estimates store m8

* produce output table, tab-delimited text
estout * using tableA1.txt, stats(r2 N N_g rss) cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) margin legend replace
estimates clear

* --------------------------------------------------------------------
* descriptive statistics
* --------------------------------------------------------------------

sum popcity popcnorm lnpopcnorm if sample
